@@ -522,7 +522,7 @@ main (int argc, char *argv[])
   menu_radio_on = gtk_menu_item_new_with_label (_("Switch radio on"));
   menu_radio_off = gtk_menu_item_new_with_label (_("Switch radio off"));
   menu_devices = gtk_menu_item_new_with_label (_("Devices..."));
-  menu_remove = gtk_menu_item_new_with_label (_("Remove from dock"));
+  menu_remove = gtk_menu_item_new_with_label (_("Remove from panel"));
 
   g_signal_connect (G_OBJECT (menu_radio_on), "activate", G_CALLBACK (radio_on), NULL);
   g_signal_connect (G_OBJECT (menu_radio_off), "activate", G_CALLBACK (radio_off), NULL);
